==> pmml-model-1.0.6-sources.jar: org/dmg/pmml/DataDictionary.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3._2001.xmlschema.Adapter2;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}DataField" maxOccurs="unbounded"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Taxonomy" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="numberOfFields" type="{http://www.w3.org/2001/XMLSchema}nonNegativeInteger" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "dataFields",
    "taxonomies"
})
@XmlRootElement(name = "DataDictionary")
public class DataDictionary
    extends PMMLObject
    implements Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "DataField", required = true)
    protected List<DataField> dataFields;
    @XmlElement(name = "Taxonomy")
    protected List<Taxonomy> taxonomies;
    @XmlAttribute(name = "numberOfFields")
    @XmlJavaTypeAdapter(Adapter2 .class)
    @XmlSchemaType(name = "nonNegativeInteger")
    protected Integer numberOfFields;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the dataFields property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the dataFields property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getDataFields().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link DataField }
     * 
     * 
     */
    public List<DataField> getDataFields() {
        if (dataFields == null) {
            dataFields = new ArrayList<DataField>();
        }
        return this.dataFields;
    }

    /**
     * Gets the value of the taxonomies property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the taxonomies property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTaxonomies().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Taxonomy }
     * 
     * 
     */
    public List<Taxonomy> getTaxonomies() {
        if (taxonomies == null) {
            taxonomies = new ArrayList<Taxonomy>();
        }
        return this.taxonomies;
    }

    /**
     * Gets the value of the numberOfFields property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getNumberOfFields() {
        return numberOfFields;
    }

    /**
     * Sets the value of the numberOfFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNumberOfFields(Integer value) {
        this.numberOfFields = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof DataDictionary)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final DataDictionary that = ((DataDictionary) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            List<DataField> lhsDataFields;
            lhsDataFields = (((this.dataFields!= null)&&(!this.dataFields.isEmpty()))?this.getDataFields():null);
            List<DataField> rhsDataFields;
            rhsDataFields = (((that.dataFields!= null)&&(!that.dataFields.isEmpty()))?that.getDataFields():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "dataFields", lhsDataFields), LocatorUtils.property(thatLocator, "dataFields", rhsDataFields), lhsDataFields, rhsDataFields)) {
                return false;
            }
        }
        {
            List<Taxonomy> lhsTaxonomies;
            lhsTaxonomies = (((this.taxonomies!= null)&&(!this.taxonomies.isEmpty()))?this.getTaxonomies():null);
            List<Taxonomy> rhsTaxonomies;
            rhsTaxonomies = (((that.taxonomies!= null)&&(!that.taxonomies.isEmpty()))?that.getTaxonomies():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "taxonomies", lhsTaxonomies), LocatorUtils.property(thatLocator, "taxonomies", rhsTaxonomies), lhsTaxonomies, rhsTaxonomies)) {
                return false;
            }
        }
        {
            Integer lhsNumberOfFields;
            lhsNumberOfFields = this.getNumberOfFields();
            Integer rhsNumberOfFields;
            rhsNumberOfFields = that.getNumberOfFields();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numberOfFields", lhsNumberOfFields), LocatorUtils.property(thatLocator, "numberOfFields", rhsNumberOfFields), lhsNumberOfFields, rhsNumberOfFields)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            List<DataField> theDataFields;
            theDataFields = (((this.dataFields!= null)&&(!this.dataFields.isEmpty()))?this.getDataFields():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "dataFields", theDataFields), currentHashCode, theDataFields);
        }
        {
            List<Taxonomy> theTaxonomies;
            theTaxonomies = (((this.taxonomies!= null)&&(!this.taxonomies.isEmpty()))?this.getTaxonomies():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "taxonomies", theTaxonomies), currentHashCode, theTaxonomies);
        }
        {
            Integer theNumberOfFields;
            theNumberOfFields = this.getNumberOfFields();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numberOfFields", theNumberOfFields), currentHashCode, theNumberOfFields);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            List<DataField> theDataFields;
            theDataFields = (((this.dataFields!= null)&&(!this.dataFields.isEmpty()))?this.getDataFields():null);
            strategy.appendField(locator, this, "dataFields", buffer, theDataFields);
        }
        {
            List<Taxonomy> theTaxonomies;
            theTaxonomies = (((this.taxonomies!= null)&&(!this.taxonomies.isEmpty()))?this.getTaxonomies():null);
            strategy.appendField(locator, this, "taxonomies", buffer, theTaxonomies);
        }
        {
            Integer theNumberOfFields;
            theNumberOfFields = this.getNumberOfFields();
            strategy.appendField(locator, this, "numberOfFields", buffer, theNumberOfFields);
        }
        return buffer;
    }

}

==> pmml-model-1.0.9-sources.jar: org/dmg/pmml/DataDictionary.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlTransient;
import javax.xml.bind.annotation.XmlType;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
import com.sun.xml.bind.Locatable;
import com.sun.xml.bind.annotation.XmlLocation;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;
import org.w3._2001.xmlschema.Adapter2;
import org.xml.sax.Locator;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}DataField" maxOccurs="unbounded"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Taxonomy" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="numberOfFields" type="{http://www.w3.org/2001/XMLSchema}nonNegativeInteger" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "dataFields",
    "taxonomies"
})
@XmlRootElement(name = "DataDictionary")
public class DataDictionary
    extends PMMLObject
    implements Locatable, Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "DataField", required = true)
    protected List<DataField> dataFields;
    @XmlElement(name = "Taxonomy")
    protected List<Taxonomy> taxonomies;
    @XmlAttribute(name = "numberOfFields")
    @XmlJavaTypeAdapter(Adapter2 .class)
    @XmlSchemaType(name = "nonNegativeInteger")
    protected Integer numberOfFields;
    @XmlLocation
    @XmlTransient
    protected Locator locator;

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the dataFields property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the dataFields property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getDataFields().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link DataField }
     * 
     * 
     */
    public List<DataField> getDataFields() {
        if (dataFields == null) {
            dataFields = new ArrayList<DataField>();
        }
        return this.dataFields;
    }

    /**
     * Gets the value of the taxonomies property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the taxonomies property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getTaxonomies().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Taxonomy }
     * 
     * 
     */
    public List<Taxonomy> getTaxonomies() {
        if (taxonomies == null) {
            taxonomies = new ArrayList<Taxonomy>();
        }
        return this.taxonomies;
    }

    /**
     * Gets the value of the numberOfFields property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public Integer getNumberOfFields() {
        return numberOfFields;
    }

    /**
     * Sets the value of the numberOfFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNumberOfFields(Integer value) {
        this.numberOfFields = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof DataDictionary)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final DataDictionary that = ((DataDictionary) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            List<DataField> lhsDataFields;
            lhsDataFields = (((this.dataFields!= null)&&(!this.dataFields.isEmpty()))?this.getDataFields():null);
            List<DataField> rhsDataFields;
            rhsDataFields = (((that.dataFields!= null)&&(!that.dataFields.isEmpty()))?that.getDataFields():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "dataFields", lhsDataFields), LocatorUtils.property(thatLocator, "dataFields", rhsDataFields), lhsDataFields, rhsDataFields)) {
                return false;
            }
        }
        {
            List<Taxonomy> lhsTaxonomies;
            lhsTaxonomies = (((this.taxonomies!= null)&&(!this.taxonomies.isEmpty()))?this.getTaxonomies():null);
            List<Taxonomy> rhsTaxonomies;
            rhsTaxonomies = (((that.taxonomies!= null)&&(!that.taxonomies.isEmpty()))?that.getTaxonomies():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "taxonomies", lhsTaxonomies), LocatorUtils.property(thatLocator, "taxonomies", rhsTaxonomies), lhsTaxonomies, rhsTaxonomies)) {
                return false;
            }
        }
        {
            Integer lhsNumberOfFields;
            lhsNumberOfFields = this.getNumberOfFields();
            Integer rhsNumberOfFields;
            rhsNumberOfFields = that.getNumberOfFields();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "numberOfFields", lhsNumberOfFields), LocatorUtils.property(thatLocator, "numberOfFields", rhsNumberOfFields), lhsNumberOfFields, rhsNumberOfFields)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            List<DataField> theDataFields;
            theDataFields = (((this.dataFields!= null)&&(!this.dataFields.isEmpty()))?this.getDataFields():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "dataFields", theDataFields), currentHashCode, theDataFields);
        }
        {
            List<Taxonomy> theTaxonomies;
            theTaxonomies = (((this.taxonomies!= null)&&(!this.taxonomies.isEmpty()))?this.getTaxonomies():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "taxonomies", theTaxonomies), currentHashCode, theTaxonomies);
        }
        {
            Integer theNumberOfFields;
            theNumberOfFields = this.getNumberOfFields();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "numberOfFields", theNumberOfFields), currentHashCode, theNumberOfFields);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public Locator sourceLocation() {
        return locator;
    }

    public void setSourceLocation(Locator newLocator) {
        locator = newLocator;
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            List<DataField> theDataFields;
            theDataFields = (((this.dataFields!= null)&&(!this.dataFields.isEmpty()))?this.getDataFields():null);
            strategy.appendField(locator, this, "dataFields", buffer, theDataFields);
        }
        {
            List<Taxonomy> theTaxonomies;
            theTaxonomies = (((this.taxonomies!= null)&&(!this.taxonomies.isEmpty()))?this.getTaxonomies():null);
            strategy.appendField(locator, this, "taxonomies", buffer, theTaxonomies);
        }
        {
            Integer theNumberOfFields;
            theNumberOfFields = this.getNumberOfFields();
            strategy.appendField(locator, this, "numberOfFields", buffer, theNumberOfFields);
        }
        return buffer;
    }

}
